@@ -123,7 +123,8 @@ on_server_new_connection(const Glib::RefPtr<Gio::DBus::Connection>& connection)
   std::cout << "Client connected." << std::endl
             << "Peer credentials: " << credentials_str << std::endl
             << "Negotiated capabilities: unix-fd-passing="
-            << (connection->get_capabilities() & Gio::DBus::CAPABILITY_FLAGS_UNIX_FD_PASSING)
+            << ((connection->get_capabilities() & Gio::DBus::CapabilityFlags::UNIX_FD_PASSING)
+               == Gio::DBus::CapabilityFlags::UNIX_FD_PASSING)
             << std::endl;
 
   // If there is already an active connection, do not accept this new one.
@@ -192,7 +193,7 @@ main(int, char**)
 
   std::cout << "Server is listening at: " << server->get_client_address() << "." << std::endl;
 
-  server->signal_new_connection().connect(sigc::ptr_fun(&on_server_new_connection));
+  server->signal_new_connection().connect(sigc::ptr_fun(&on_server_new_connection), false);
 
   // Keep the server running until the process is killed:
   auto loop = Glib::MainLoop::create();
