@@ -48,12 +48,18 @@
 #include <giomm/dbuserror.h>
 #include <giomm/dbuserrorutils.h>
 #include <giomm/dbusinterface.h>
+#include <giomm/dbusinterfaceskeleton.h>
 #include <giomm/dbusinterfacevtable.h>
 #include <giomm/dbusintrospection.h>
 #include <giomm/dbusmenumodel.h>
 #include <giomm/dbusmessage.h>
 #include <giomm/dbusmethodinvocation.h>
 #include <giomm/dbusobject.h>
+#include <giomm/dbusobjectmanager.h>
+#include <giomm/dbusobjectmanagerclient.h>
+#include <giomm/dbusobjectmanagerserver.h>
+#include <giomm/dbusobjectproxy.h>
+#include <giomm/dbusobjectskeleton.h>
 #include <giomm/dbusownname.h>
 #include <giomm/dbusproxy.h>
 #include <giomm/dbusserver.h>
@@ -104,6 +110,7 @@
 #include <giomm/mount.h>
 #include <giomm/mountoperation.h>
 #include <giomm/networkaddress.h>
+#include <giomm/networkmonitor.h>
 #include <giomm/networkservice.h>
 #include <giomm/notification.h>
 #include <giomm/outputstream.h>
